#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2017 lafrite <lafrite@Poivre>
#
# Distributed under terms of the MIT license.

from mapytex.calculus.core.tree import Tree
from .mo import MO

__all__ = ["MOFraction"]

class MOFraction(MO):

    """ Fraction math object"""

    def __init__(self, numerator, denominator, negative=False):
        """ Initiate the MOFraction

        It can't be indempotent.

        :param numerator: Numerator of the Fraction
        :param denominator: Denominator of the Fraction
        :param negative: Is the fraction negative (not concidering sign of
        numerator or denominator.

        >>> f = MOFraction(2, 3)
        >>> f
        <MOFraction 2 / 3>
        >>> f = MOFraction(2, 3, negative = True)
        >>> f
        <MOFraction - 2 / 3>
        """
        base_value = Tree("/",
                          MO.factory(numerator),
                          MO.factory(denominator),
                         )
        if negative:
            value = Tree("-", None, base_value)
        else:
            value = base_value
        MO.__init__(self, value)

        self._numerator = numerator
        self._denominator = denominator
        self.negative = negative

    @property
    def numerator(self):
        """ Get the numerator. If self is negative, getting the opposite of the _numerator
        """
        if self.negative:
            return Tree("-", None, self._numerator)

        return self._numerator

    @property
    def denominator(self):
        return self._denominator

    def inverse(self):
        """ return the inverse fraction """
        return MOFraction(self._denominator,
                self._numerator, 
                self.negative)

# -----------------------------
# Reglages pour 'vim'
# vim:set autoindent expandtab tabstop=4 shiftwidth=4:
# cursor: 16 del
